@@ -4,7 +4,9 @@
 
 #include <sys/stat.h>
 #include <fcntl.h>
+#ifndef WIN32
 #include <dirent.h>
+#endif
 
 #ifndef WIN32
     #include <arpa/inet.h>
@@ -33,23 +35,47 @@ struct _SeafFSManagerPriv {
     GHashTable      *bl_cache;
 };
 
+#ifdef WIN32
+typedef struct SeafileOndisk {
+    guint32          type;
+    guint64          file_size;
+    unsigned char    block_ids[0];
+} SeafileOndisk;
+#else
 typedef struct SeafileOndisk {
     guint32          type;
     guint64          file_size;
     unsigned char    block_ids[0];
 } __attribute__((__packed__)) SeafileOndisk;
+#endif
 
+#ifdef WIN32
+typedef struct DirentOndisk {
+    guint32 mode;
+    char    id[40];
+    guint32 name_len;
+    char    name[0];
+} DirentOndisk;
+#else
 typedef struct DirentOndisk {
     guint32 mode;
     char    id[40];
     guint32 name_len;
     char    name[0];
 } __attribute__((__packed__)) DirentOndisk;
+#endif
 
+#ifdef WIN32
+typedef struct SeafdirOndisk {
+    guint32 type;
+    char    dirents[0];
+} SeafdirOndisk;
+#else
 typedef struct SeafdirOndisk {
     guint32 type;
     char    dirents[0];
 } __attribute__((__packed__)) SeafdirOndisk;
+#endif
 
 #ifndef SEAFILE_SERVER
 uint32_t
@@ -364,6 +390,16 @@ seaf_fs_manager_checkout_file (SeafFSManager *mgr,
             seaf_warning ("Failed to rename %s to %s: %s. "
                           "Failed to move backup file to conflict file.\n",
                           backup_path, conflict_path, strerror(errno));
+            if (mtime > 0) {
+                /*
+                 * Set the checked out file mtime to what it has to be.
+                 */
+                if (seaf_set_file_time (file_path, mtime) < 0) {
+                    seaf_warning ("Failed to set mtime for %s.\n", file_path);
+                }
+            }
+            //Don't delete local file when failed to rename backup file to conflict file.
+            goto out;
         }
     }
 
