@@ -567,7 +567,8 @@ transition_sync_state (SyncTask *task, int new_state)
          * with DONE state. But we need to notify the user about this error in the interface.
          * Such file level errors are set with seaf_sync_manager_set_task_error_code().
          */
-        if (new_state != SYNC_STATE_ERROR && task->error != SYNC_ERROR_ID_NO_ERROR) {
+        if (new_state != SYNC_STATE_ERROR && task->error != SYNC_ERROR_ID_NO_ERROR
+            && task->error != SYNC_ERROR_ID_INVALID_PATH_ON_WINDOWS) {
             new_state = SYNC_STATE_ERROR;
             seaf_message ("Repo '%s' sync is finished but with error: %s\n",
                           task->repo->name,
@@ -2262,11 +2263,10 @@ seaf_sync_manager_update_active_path (SeafSyncManager *mgr,
             sync_status_tree_add (info->syncing_tree, path, mode, refresh);
         else if (status == SYNC_STATUS_SYNCED)
             sync_status_tree_add (info->synced_tree, path, mode, refresh);
-        else {
 #ifdef WIN32
+        else if (refresh)
             seaf_sync_manager_add_refresh_path (mgr, path);
 #endif
-        }
     } else if (existing != status) {
         g_hash_table_replace (info->paths, g_strdup(path), (void*)status);
 
@@ -2279,9 +2279,9 @@ seaf_sync_manager_update_active_path (SeafSyncManager *mgr,
             sync_status_tree_add (info->syncing_tree, path, mode, refresh);
         else if (status == SYNC_STATUS_SYNCED)
             sync_status_tree_add (info->synced_tree, path, mode, refresh);
-
 #ifdef WIN32
-        seaf_sync_manager_add_refresh_path (mgr, path);
+        else if (refresh)
+            seaf_sync_manager_add_refresh_path (mgr, path);
 #endif
     }
 
